#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:job_priority) do
  include EasyType
  include EasyType::Validators::Integer
  include EasyType::Mungers::Integer
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-EOD
    Specifies the priority for the job.

    Here is an example on how to use this:

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          job_priority => 'DEFAULT_JOB_CLASS',
          ...
        }

    Default value: 3

  EOD

  defaultto 3

  newvalues(1, 2, 3, 4, 5)

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('JOB_PRIORITY')
  end

  on_modify do
    statement = template('ora_config/ora_scheduler_job/modify_unquoted_attribute.sql.erb', binding)
    sql statement, {:sid => resource.sid}
  end

end
