#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:replay_init_time) do
  include Puppet_X::EnterpriseModules::Oracle::ServiceProperty
  include EasyType::Validators::Integer
  include EasyType::Mungers::Integer

  desc <<-EOD
    For Application Continuity, this parameter specifies the difference between the time, in seconds,
    of original execution of the first operation of a request and the time that the replay is ready
    to start after a successful reconnect. Application Continuity will not replay after the specified
    amount of time has passed. This parameter is intended to avoid the unintentional execution of a
    transaction when a system is recovered after a long period.
    If the `failover_type` parameter is not set to TRANSACTION, then you cannot use this parameter.

    Here is an example on how to use this:

        ora_service{'my_service':
          ...
          replay_init_time => 300,
          ...
        }

    Puppet provides no default value. But Oracle might, depending on your version.

    This is a cluster only property. On single node database this property will be ignored. If you use it,
    Puppet will issue a warning.

  EOD

  column_name 'Replay Initiation Time'
end
