#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:state) do
  include Puppet_X::EnterpriseModules::Oracle::ServiceProperty
  include Puppet_X::EnterpriseModules::Oracle::Commands

  desc <<-EOD
    When a service is disabled Oracle Clusterware will not automatically start, failover or restart
    the service for maintenance purposes.

    Here is an example on how to use this:

        ora_service{'my_service':
          ...
          state => 'DISABLED',
          ...
        }

    Puppet provides no default value. But Oracle might, depending on your version.

    This is a cluster only property. On single node database this property will be ignored. If you use it,
    Puppet will issue a warning.

  EOD

  column_name 'Service is'
  newvalues(:ENABLED, :DISABLED, :enabled, :disabled)

  def insync?(_is)
    return true unless cluster?
    provider.state.casecmp(resource.state.to_s) != 0 ? false : true
  end

  on_modify do
    if cluster?
      srvctl("#{state_value} service -d #{dbname} -s #{resource.service_name}", { :sid => sid })
    else
      nil
    end
  end

  def state_value
    case value
      when :enabled, :ENABLED
      then 'enable'
      else 'disable'
    end
  end

  def dbname
    sid ? sid.chop : default_database_sid.chop
  end
end
