#
# See the file "LICENSE" for the full license governing this code.
#
# TODO: Check values
newproperty(:max_size) do
  include EasyType
  include TablespaceType
  include Puppet_X::EnterpriseModules::Oracle::Access
  include Puppet_X::EnterpriseModules::Oracle::DatafileProperty

  desc <<-EOD
    Maximum size for autoextending.
  EOD

  def munge(size)
    return size if size.is_a?(Numeric)
    case size
    when /^\d+(K|k)$/ then size.chop.to_i * 1024
    when /^\d+(M|m)$/ then size.chop.to_i * 1024 * 1024
    when /^\d+(G|g)$/ then size.chop.to_i * 1024 * 1024 * 1024
    when /^unlimited$/ then 'unlimited'
    when /^\d+$/ then size.to_i
    else
      fail('invalid size')
    end
  end

  # TODO: Check why it doesn't return the right values
  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('MAX_SIZE').to_f.to_i
  end

  on_create do
    if resource[:autoextend] == :on
      "maxsize #{value}" unless df_array_size(provider.datafile) > 1 || desired_num_datafiles > 1
    else
      Puppet.warning "#{path}: property max_size changed on ora_tablespace[#{resource[:name]}], but autoextend is off. Change has no effect. "
      nil
    end
  end

  def insync?(value)
    if resource.max_size == 'unlimited'
      # translate unlimited to an actual size so we can compare it
      bs = provider.block_size.to_i
      if provider.bigfile == :yes || resource.bigfile == :yes
        value = (value + 2 * bs) / 4_294_967_295 == bs ? 'unlimited' : 4_294_967_295 * bs - 2 * bs
      else
        value = (value + bs) / 4_194_303 == bs ? 'unlimited' : 4_194_303 * bs - bs
      end
    end
    value == resource.max_size
  end
end
